Re: [U-Boot] [PATCH 1/6] mpc512x: make MEM IO Control configuration a board config option

2010-03-21 Thread Wolfgang Denk
Dear Anatolij Gustschin,

In message 1266964630-7754-2-git-send-email-ag...@denx.de you wrote:
 Signed-off-by: Anatolij Gustschin ag...@denx.de
 ---
  cpu/mpc512x/fixed_sdram.c|2 +-
  include/asm-ppc/immap_512x.h |4 
  include/configs/aria.h   |2 ++
  include/configs/mecp5123.h   |2 ++
  include/configs/mpc5121ads.h |2 ++
  5 files changed, 7 insertions(+), 5 deletions(-)

Applied to u-boot-mpc5xxx repo, thanks.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
If A equals success, then the formula is A = X + Y + Z. X is work.  Y
is play. Z is keep your mouth shut. - Albert Einstein
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH 2/6] mpc512x: add multi serial PSC support

2010-03-21 Thread Wolfgang Denk
Dear Anatolij Gustschin,

In message 1266964630-7754-3-git-send-email-ag...@denx.de you wrote:
 Extend mpc512x serial driver to support multiple PSCs ports.
 
 Supsequent patches for PDM360NG board support make use of this
 functionality by defining CONFIG_SERIAL_MULTI in the board config
 file. Additionally the used PSC devices are specified by defining
 e.g. CONFIG_SYS_PSC1, CONFIG_SYS_PSC4 and CONFIG_SYS_PSC6.
 
 Support for PSC devices other than 1, 3, 4 and 6 is not added
 by this patch because these aren't used currently. In the future
 it can be easily added using DECLARE_PSC_SERIAL_FUNCTIONS(N) and
 INIT_PSC_SERIAL_STRUCTURE(N) macros in cpu/mpc512x/serial.c.
 Additionally you have to add code for registering added
 devices in serial_initialise() in common/serial.c.
 
 Signed-off-by: Anatolij Gustschin ag...@denx.de
 ---
  common/serial.c  |   23 
  cpu/mpc512x/serial.c |  266 
 +-
  include/asm-ppc/immap_512x.h |  108 +-
  include/serial.h |8 ++
  4 files changed, 324 insertions(+), 81 deletions(-)

Applied to u-boot-mpc5xxx repo, thanks.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Gods don't like people not doing much work. People  who  aren't  busy
all the time might start to _think_.  - Terry Pratchett, _Small Gods_
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH 3/6] mpc5121: add PSC serial communication routines

2010-03-21 Thread Wolfgang Denk
Dear Anatolij Gustschin,

In message 1266964630-7754-4-git-send-email-ag...@denx.de you wrote:
 Signed-off-by: Anatolij Gustschin ag...@denx.de
 ---
  cpu/mpc512x/serial.c |   87 
 ++
  include/serial.h |7 
  2 files changed, 94 insertions(+), 0 deletions(-)

Applied to u-boot-mpc5xxx repo, thanks.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Space is big. You just won't believe how vastly, hugely, mind-
bogglingly big it is. I mean, you may think it's a long way down the
road to the drug store, but that's just peanuts to space.
  -- The Hitchhiker's Guide to the Galaxy
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH 4/6] fsl_diu_fb.c: add support for RLE8 bitmaps

2010-03-21 Thread Wolfgang Denk
Dear Anatolij Gustschin,

In message 1266964630-7754-5-git-send-email-ag...@denx.de you wrote:
 Allow displaying run length encoded bitmaps.
 
 Signed-off-by: Anatolij Gustschin ag...@denx.de
 ---
  board/freescale/common/fsl_diu_fb.c |   78 
 +++
  1 files changed, 78 insertions(+), 0 deletions(-)


Applied to u-boot-mpc5xxx repo, thanks.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
The only person who always got his work done by Friday
 was Robinson Crusoe.
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH 5/6] fdt_support: add partitions fixup in mtd node

2010-03-21 Thread Wolfgang Denk
Dear Anatolij Gustschin,

In message 1266964630-7754-6-git-send-email-ag...@denx.de you wrote:
 Allow overriding defined partitions in the device tree blob
 using partition info defined in the 'mtdparts' environment
 variable.
 
 Signed-off-by: Anatolij Gustschin ag...@denx.de
 Cc: Gerald Van Baren vanba...@cideas.com
 ---
  common/cmd_mtdparts.c   |2 +-
  common/fdt_support.c|  214 
 +++
  include/fdt_support.h   |2 +
  include/jffs2/load_kernel.h |1 +
  include/mtd_node.h  |   11 ++
  5 files changed, 229 insertions(+), 1 deletions(-)
  create mode 100644 include/mtd_node.h

Applied to next branch, thanks.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Infidels in all ages have battled for the rights of man, and have at
all times been the fearless advocates of liberty and justice.
- Robert Green Ingersoll
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH 6/6] mpc5121: add support for PDM360NG board

2010-03-21 Thread Wolfgang Denk
Dear Anatolij Gustschin,

In message 1266964630-7754-7-git-send-email-ag...@denx.de you wrote:
 --===1816892533==
 
 PDM360NG is a MPC5121E based board by ifm ecomatic gmbh.
 
 Signed-off-by: Michael Weiss michael.we...@ifm.com

Incorrect mail address format.

 Signed-off-by: Anatolij Gustschin ag...@denx.de
 ---
  MAKEALL |1 +
  Makefile|3 +
  board/freescale/common/fsl_diu_fb.c |   29 ++-
  board/pdm360ng/Makefile |   51 +++
  board/pdm360ng/config.mk|   24 ++
  board/pdm360ng/pdm360ng.c   |  618 
 +++
  cpu/mpc512x/diu.c   |   14 +-
  include/configs/pdm360ng.h  |  525 +
  include/post.h  |1 +
  post/tests.c|4 +
  10 files changed, 1264 insertions(+), 6 deletions(-)
  create mode 100644 board/pdm360ng/Makefile
  create mode 100644 board/pdm360ng/config.mk
  create mode 100644 board/pdm360ng/pdm360ng.c
  create mode 100644 include/configs/pdm360ng.h

Entry to MAINTAINERS file is missing.

...
 +#if defined(CONFIG_HARD_I2C)
 + if (!getenv(ethaddr)) {
 + uchar buf[6];
 + char mac[18];
 + int ret;
 +
 + /* I2C-0 for on-board eeprom */
 + i2c_set_bus_num(CONFIG_SYS_I2C_EEPROM_BUS_NUM);
 +
 + /* Read ethaddr from EEPROM */
 + ret = i2c_read(CONFIG_SYS_I2C_EEPROM,
 +CONFIG_SYS_I2C_EEPROM_MAC_OFFSET, 1, buf, 6);
 + if (!ret) {
 + sprintf(mac, %02X:%02X:%02X:%02X:%02X:%02X,
 + buf[0], buf[1], buf[2], buf[3], buf[4], buf[5]);

If you really want to do this, then please use

sprintf(mac, %pM, buf);

instead.

 + /* Owned by IFM ? */
 + if (strstr(mac, 00:02:01) != mac) {
 + printf(Illegal MAC address in EEPROM: %s\n,
 +mac);

Why not simply a memcmp() or a strncmp() ?

 + } else {
 + debug(Using MAC from I2C EEPROM: %s\n, mac);
 + setenv(ethaddr, mac);
 + }
 + } else {
 + printf(Error: Unable to read MAC from I2C
 +  EEPROM at address %02X:%02X\n,
 + CONFIG_SYS_I2C_EEPROM,
 + CONFIG_SYS_I2C_EEPROM_MAC_OFFSET);
 + }

All this seems overly complicated to me. All these string conversions
are not really needed. Why not like this:

uchar ifm_oui[3] = { 0, 2, 1, };

ret = i2c_read(...);
if (ret != 0) {
printf(Error: Unable to read MAC from I2C
 EEPROM at address %02X:%02X\n,
CONFIG_SYS_I2C_EEPROM,
CONFIG_SYS_I2C_EEPROM_MAC_OFFSET);
return 0;
/* or rather return 1;  ??? */
}

if (memcmp(buf, ifm_oui, sizeof(ifm_oui)) {
printf(Illegal MAC address in EEPROM: %pM\n,
buf):
}

eth_setenv_enetaddr(ethaddr, buf);

 +#if defined(CONFIG_SERIAL_MULTI)
 +/*
 + * If argument is NULL, set the LCD brightness to the
 + * value from brightness environment variable. Set
 + * the LCD brightness to the value specified by the
 + * argument otherwise. Default brightness is zero.
 + */
 +#define MAX_BRIGHTNESS   99
 +static int set_lcd_brightness(char *brightness)

This seems wrong to me. Why does LCD related code depend on
CONFIG_SERIAL_MULTI ???


 diff --git a/cpu/mpc512x/diu.c b/cpu/mpc512x/diu.c
 index a24f395..fc43a9d 100644
 --- a/cpu/mpc512x/diu.c
 +++ b/cpu/mpc512x/diu.c
 @@ -68,8 +68,13 @@ char *valid_bmp(char *addr)
   unsigned long h_addr;
  
   h_addr = simple_strtoul(addr, NULL, 16);
 - if (h_addr  CONFIG_SYS_FLASH_BASE ||
 - h_addr = (CONFIG_SYS_FLASH_BASE + 
 CONFIG_SYS_FLASH_SIZE - 1)) {
 + if ((h_addr  CONFIG_SYS_FLASH_BASE ||
 + h_addr = (CONFIG_SYS_FLASH_BASE + CONFIG_SYS_FLASH_SIZE - 1))
 +#if defined(CONFIG_SYS_FLASH1_BASE)  defined(CONFIG_SYS_FLASH1_SIZE)
 + (h_addr  CONFIG_SYS_FLASH1_BASE ||
 +h_addr = (CONFIG_SYS_FLASH1_BASE + CONFIG_SYS_FLASH1_SIZE - 1))
 +#endif
 + ) {

I don't like this.  Why do we see hardcoded values here and not the
data from the CFI driver's auto-sizing?  I assume both flash banks are
maped into one big contiguous array of NOR flash, right? Then there
should be just a single test for  base || (base+size) here, using
the total size of the combined flash banks.


   printf(bmp addr %lx is not a valid flash address\n, h_addr);
   return 0;

And why would it be necessary that the BMP resides in NOR flash in the
first place?

Why cannot - for 

Re: [U-Boot] The abortboot routine misses key hits issued via netconsole.

2010-03-21 Thread Wolfgang Denk
Dear Michael Zaidman,

In message 660c0f821002240238t71a6d793we93747bbb8bb8...@mail.gmail.com you 
wrote:
 
 The Hit any key to stop autoboot: of abortboot routine misses
 the key hits issued via netconsole.
 It happens due to delays of 10ms used to count passed seconds in
 the abortboot routine of main.c file. All key events arrived
 asynchronously during these delays are lost.

If I understand your message correctly you did not try changing this
10ms delay?

I mean, functionally it makes no difference if we implement the 1
second delay loop as 100 iterations of 10 ms or as 1,000 iterations
of 1 ms or as 10,000 iterations of 100 us. OK, the shorter the delay
the worse the accuracy due to the per-loop overhead, but this could be
easily fixed if it really was a problem.

Maybe you can try of 1000*1ms or 10,000*0.1ms works for you?

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Advice is seldom welcome; and those who want it the most always like
it the least. -- Philip Earl of Chesterfield
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH v3 7/7] cmd_setexpr: allow memory addresses in expressions

2010-03-21 Thread Wolfgang Denk
Dear Frans Meulenbroeks,

In message 1267189219-6712-1-git-send-email-fransmeulenbro...@gmail.com you 
wrote:
 This patch add functionality to use memory addresses in expressions.
 This increases the power of expressions substantially
 
 It adheres to the standard convemtions: memory addresses can be given in the 
 format
 *address (e.g. *1000)
 
 Rationale for this change is that it allows masking off bits from a byte that 
 is
 obtained by reading data from e.g. i2c.
 
 Signed-off-by: Frans Meulenbroeks fransmeulenbro...@gmail.com
 ---
 
  common/cmd_setexpr.c |   29 +
  1 files changed, 25 insertions(+), 4 deletions(-)

Applied to next branch, thanks.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
The majority of the stupid is  invincible  and  guaranteed  for  all
time.  The  terror  of their tyranny, however, is alleviated by their
lack of consistency.   - Albert Einstein
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] The abortboot routine misses key hits issued via netconsole.

2010-03-21 Thread Michael Zaidman
On Sun, Mar 21, 2010 at 2:35 PM, Wolfgang Denk w...@denx.de wrote:
 Dear Michael Zaidman,

 In message 660c0f821002240238t71a6d793we93747bbb8bb8...@mail.gmail.com you 
 wrote:

 The Hit any key to stop autoboot: of abortboot routine misses
 the key hits issued via netconsole.
 It happens due to delays of 10ms used to count passed seconds in
 the abortboot routine of main.c file. All key events arrived
 asynchronously during these delays are lost.

 If I understand your message correctly you did not try changing this
 10ms delay?

 I mean, functionally it makes no difference if we implement the 1
 second delay loop as 100 iterations of 10 ms or as 1,000 iterations
 of 1 ms or as 10,000 iterations of 100 us. OK, the shorter the delay
 the worse the accuracy due to the per-loop overhead, but this could be
 easily fixed if it really was a problem.

 Maybe you can try of 1000*1ms or 10,000*0.1ms works for you?

 Best regards,

 Wolfgang Denk


I got your point... It may reduce the number of key misses by the
nc_tstc but will not eliminate the key misses at all. In current
implementation the netconsole interface while calling the nc_tstc() is
able to capture the pressed key during extremely short period of time
only – starting from the eth_init() until testing for incoming packet
in the Netloop routine. The related overhead for rest of the loop and
especially for eth_halt() and eth_init() is significantly longer then
active “ready to receive” window event if we will call only the
nc_tstc() in loop with no abortboot() involved at all. My coarse
estimation of “ready to receive/not ready” states duty cycle is far
worse than 1:10, i.e. lesser than 10% probability of success.  Now,
with abortboot() added it changes this ratio to be even worse making
capturing the key via netconsole interface almost impossible.

BTW, increasing by 10 the time of “ready to receive” state in
nc_tstc() as in described by me solution changed probability of key
capturing to ~ 90% but not eliminate the key misses completely.

Regards,
Michael
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH] cmd_mmc remove \n

2010-03-21 Thread Wolfgang Denk
Dear Frans Meulenbroeks,

In message 1267102988-9116-1-git-send-email-fransmeulenbro...@gmail.com you 
wrote:
 This patch removed the \n after the help message for mmcinfo.
 This one resulted in an empty line being displayed after the mmcinfo line
 when the help command was given.
 
 Signed-off-by: Frans Meulenbroeks fransmeulenbro...@gmail.com
 ---
  common/cmd_mmc.c |2 +-
  1 files changed, 1 insertions(+), 1 deletions(-)

Applied, thanks.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
A little knowledge is a dangerous thing.- Doug Gwyn
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH] POST progress API

2010-03-21 Thread Wolfgang Denk
Dear Michael Zaidman,

In message 1267436856-3933-1-git-send-email-michael.zaid...@gmail.com you 
wrote:
 Added POST progress API implemented as weak calls before and after
 each call to the POST test callback in the post_run_single routine
 of the post.c file.
 
 Signed-off-by: Michael Zaidman michael.zaid...@gmail.com
 ---
  include/post.h |5 +
  post/post.c|   17 +++--
  2 files changed, 20 insertions(+), 2 deletions(-)

Applied to next branch.  Thanks.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Thought for the day: What if there were no hypothetical situations?
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH] POST progress API

2010-03-21 Thread Wolfgang Denk
Dear Michael Zaidman,

In message 660c0f821003160321h1a5552dfh6cc835b48b004...@mail.gmail.com you 
wrote:
 
 Is there a chance this patch will be included already in this release?

Sorry, but no. This is new code (i. e. not a bug fix) and thus has to
wait for the next merge window.  We pull it into the next branch now
so that it is in fact already on the fast-lane there.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
A verbal contract isn't worth the paper it's written on.
-- Samuel Goldwyn
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] The abortboot routine misses key hits issued via netconsole.

2010-03-21 Thread Michael Zaidman
 capturing to ~ 90% but not eliminate the key misses completely.
Small correction - more than 99,9% - ration between 1 second and 100
times of loop overhead.
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH] Add support for Indefia Nimbus Cloud Board

2010-03-21 Thread Wolfgang Denk
Dear Semih Hazar,

In message 4b6b004c.1010...@indefia.com you wrote:
 
 The problem with AVR32 and the CFI flash driver has a few possible
 solutions as noted by Haavard Skinnemoen in the email [1]. The only
 thing I can do is to go with the first alternative and set the flash
 address as the virtual address which is cache-disabled and works
 flawless with the CFI driver.
 
 That solution can also be used by other AVR32 boards, and I _think_ it
 also solves the JFFS2 scanning problem which was mentioned in [2].
 
 The only ugly thing (for me) is when using the CFI commands, the flash
 addresses has to be shifted by 0xa000. (e.g. copy to flash at 0x1000
 must be written as cp.b source 0xa0001000 size).

I really dislike such an approach.  From the user interface point of
view this is unacceptable to me.


My understanding is that there are only three pretty local areas where
uncached access to the flash is needed: initialization (i. e. probing
and querying), erasing, and programming.

So it should be possible to switch off caching when entering these
functions, and turn it on again upon return.  Eventually other
architectures might want to implement such a feature, too, so adding
generic infrastructure to do that makes sense to me.

Stefan might want to comment here, too ?

In worst case (if you really cannot change the caching attributes for
the flash memory region on the fly) it might even be possible to add
some address offset which is strictly internal to the CFI driver
and used for the nn-cached accesses. But in now way any of this
should be visible to the end user on the command line.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Ada is PL/I trying to be Smalltalk. - Codoso diBlini
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH] Add support for Indefia Nimbus Cloud Board

2010-03-21 Thread Wolfgang Denk
Dear Semih Hazar,

In message 4b8bcb49.4000...@indefia.com you wrote:
 
 It's been a while over this issue, so I wanted to ask. Did you have time
 to look at this?

I looked at it now. Please see my previous message.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
No one talks peace unless he's ready to back it up with war.
He talks of peace if it is the only way to live.
-- Colonel Green and Surak of Vulcan, The Savage Curtain,
   stardate 5906.5.
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH] POST progress API

2010-03-21 Thread Michael Zaidman
On Sun, Mar 21, 2010 at 6:17 PM, Wolfgang Denk w...@denx.de wrote:
 Dear Michael Zaidman,

 In message 660c0f821003160321h1a5552dfh6cc835b48b004...@mail.gmail.com you 
 wrote:

 Is there a chance this patch will be included already in this release?

 Sorry, but no. This is new code (i. e. not a bug fix) and thus has to
 wait for the next merge window.  We pull it into the next branch now
 so that it is in fact already on the fast-lane there.

 Best regards,

 Wolfgang Denk

Thanks,
Michael
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH] Add support for Indefia Nimbus Cloud Board

2010-03-21 Thread Wolfgang Denk
Dear Semih Hazar,

In message 4b6b0058.2090...@indefia.com you wrote:
 Nimbus Cloud is an AVR32 based single board computer with
 256MiB NAND, 64MiB SDRAM, battery backed RTC, LCD/touch
 screen support, VGA Output, Ethernet and offers seamless
 integration with Indefia's Zigbee transceivers.
 
 ---
  CREDITS |4 +
  MAINTAINERS |4 +
  MAKEALL |1 +
  Makefile|3 +
  board/indefia/nimbuscloud/Makefile  |   40 +++
  board/indefia/nimbuscloud/config.mk |3 +
  board/indefia/nimbuscloud/nimbuscloud.c |  165 +++
  board/indefia/nimbuscloud/nimbuscloud.h |8 ++
  board/indefia/nimbuscloud/u-boot.lds|   72 
  include/configs/nimbuscloud.h   |  184 
 +++
  10 files changed, 484 insertions(+), 0 deletions(-)

I am not sure how this patch addresses the previously discussed topic
of cached/uncached accesses to the NOR flash. It does not mention the
topic anywhere in the commit message or other comments, which I
consider a serious flaw of the patch.

From the

#define CONFIG_SYS_FLASH_BASE  0xa000

I understand that this is the version where the end user has to deal
with two different address ranges (i. e. md 1 would be used
to dump the 2nd 64kB-sector, while era A001 would be needed to
erase the same sector.

Such behaviour is seems unacceptable to me. If my understanding is
corrent, I tend to reject this patch. [Please see explanations in
previous messages for other options to solve this issue.]

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
The IQ of the group is the lowest IQ of a member of the group divided
by the number of people in the group.
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] 8/16 bit support for NAND at runtime

2010-03-21 Thread Wolfgang Denk
Dear Vipin KUMAR,

In message 4b908bc8.9030...@st.com you wrote:

  Why would that be needed? Do you really expect to see both types of
  interfaces on the same piece of hardware?
 
 Yes, that's precisely the case with Spear SoC. It has an FSMC controller
 embedded in it. FSMC can support 8 as well as 16 bit devices(off-course
 with different initializations) for different banks

The fact that it _can_ support different bus widths does not mean that
anybody would go on and use both at the same time on the same board.

Do you really have any proof that ther eexisits any piece of hardware
that has both an 8 bit and a 16 bit NAND flash on it?

  Otherwise you just have misconfigured your board, and fixing the
  configuration should all that is needed to make the code work.  Or am
  I missing something?
 
 I could make the code work with both 8 as well as 16 bit devices. The
 only thing is that I have to make a few changes and rebuild the uboot
 for a particular interface

It seems to be no real problem to me when you have to reconfigure
U-Boot and build another image when switching to another piece of
hardware that is incompatible enough to use different bus widths.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Witch!  Witch!  They'll burn ya!
-- Hag, Tomorrow is Yesterday, stardate unknown
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [Patch] ./drivers/pci/pci.c

2010-03-21 Thread Wolfgang Denk
Dear FUJITA Kazutoshi,

In message 20100309.232841.106130457.fuj...@soum.co.jp you wrote:

 Subject: Re: [U-Boot] [Patch] ./drivers/pci/pci.c
 Date: Tue, 09 Mar 2010 14:27:25 +0100
 
  Please provide a useful commit message, and add your Signed-off-by:
  line.
 
 sorry, how about this?
 
 regards,

That's actually still nort usable.

First, the Subject line would result in a commit message tile of
./drivers/pci/pci.c - do you think this is a meaningful description
of what this patch is doing?

Second, all the above text would become part of the commit message -
this makes no sense either.

Please use git-format-patch to format the patches, add commets _below_
the --- line, and use git-send-email to submit the patches.

 this patch fixes to deal with PCI_BASE_ADDRESS_5 which was forgotten
 in pci_hose_config_device()
 
 Signed-off-by: FUJITA Kazutoshi fuj...@soum.co.jp
 
 
 diff --git a/drivers/pci/pci.c b/drivers/pci/pci.c
 index d6d2d6e..cd64a87 100644
 --- a/drivers/pci/pci.c
 +++ b/drivers/pci/pci.c
 @@ -388,7 +388,7 @@ int pci_hose_config_device(struct pci_controller *hose,

I edited the commit message for you, and applied the patch now.
Thanks.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
You're just jealous. What, of an overgrown puppy  with  a  single-
figure IQ?  - Terry Pratchett, _Moving Pictures_
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] EABI 4.2

2010-03-21 Thread Wolfgang Denk
Dear Tom,

In message 20100317161258.76fee...@marrow.netinsight.se Simon
Kagstrom wrote:
 On Wed, 17 Mar 2010 09:53:36 -0500
 Praveen G K praveen...@gmail.com wrote:
 
   I had a similar problem a few months ago, which turned out to be a
   stack alignment issue:
  
   =A0http://www.mail-archive.com/u-boot@lists.denx.de/msg23202.html
  
   the behavior was pretty similar, with code built with some compilers
   working (by chance) and some others breaking.
  =
 
  Great! This does work when added to cpu/arm1176/start.S
  Is there any specific reason why this was not added to the arm11 stream?
 
 Well, none other than that I didn't realise it affected other platforms
 as well. Looking at the tip, it seems like pretty much all ARM
 platforms are susceptible to this issue. So a mass-fix would probably
 be in place.

This seems serious enough to me that we should try to get this fixed
in the upcoming release.  Do you think you can manage this?

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Einstein argued that there must be simplified explanations of nature,
because God is not capricious or arbitrary. No  such  faith  comforts
the software engineer. - Fred Brooks, Jr.
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH] TFTP: allow for adjustable retransmission timout

2010-03-21 Thread Wolfgang Denk
Dear Ben,

In message 4b9977eb.7020...@gmail.com you wrote:
 
  What's the status of this patch? Is it on your queue?
 
 So sorry - I thought I'd already taken care of this.  Please feel free 
 to add my SOB and apply directly.
 
 Signed-off-by: Ben Warren biggerbadder...@gmail.com

Done, thanks.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Every time history repeats itself the price goes up.
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH 3/3] fsl_esdhc: Only modify the field we are changing in WML

2010-03-21 Thread Kumar Gala

On Mar 20, 2010, at 12:59 PM, Stefano Babic wrote:

 Kumar Gala wrote:
 From: Roy Zang tie-fei.z...@freescale.com
 
 When we set the read or write watermark in WML we should maintain the
 rest of the register as is, rather than using some hard coded value.
 
 Signed-off-by: Roy Zang tie-fei.z...@freescale.com
 Signed-off-by: Kumar Gala ga...@kernel.crashing.org
 ---
 * This patch supercededs (fsl_esdhc: Only modify WML[WR] field)
 
 Hi,
 
 +esdhc_clrsetbits32(regs-wml, WML_WR_WML_MASK, wml_value  
 16);
 
 Line too long.
 
 Tested successfully on mx51evk.
 
 Acked-by: Stefano Babic sba...@denx.de
 
 Regards,
 Stefano

Thanks, will fix the line length in my git tree commit.

- k
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


[U-Boot] [PATCH] nios2: Add missing Ethernet initialization to board_init().

2010-03-21 Thread Scott McNutt
Signed-off-by: Scott McNutt smcn...@psyent.com
---
 lib_nios2/board.c |8 
 1 files changed, 8 insertions(+), 0 deletions(-)

diff --git a/lib_nios2/board.c b/lib_nios2/board.c
index 41d3297..311d66c 100644
--- a/lib_nios2/board.c
+++ b/lib_nios2/board.c
@@ -139,6 +139,14 @@ void board_init (void)
board_late_init ();
 #endif
 
+#if defined(CONFIG_CMD_NET)
+#if defined(CONFIG_NET_MULTI)
+   WATCHDOG_RESET ();
+   puts (Net:   );
+#endif
+   eth_initialize (bd);
+#endif
+
/* main_loop */
for (;;) {
WATCHDOG_RESET ();
-- 
1.6.0.6

___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH] nios2: Add missing Ethernet initialization to board_init().

2010-03-21 Thread Mike Frysinger
On Sunday 21 March 2010 13:37:53 Scott McNutt wrote:
 + WATCHDOG_RESET ();
 + puts (Net:   );

considering serial drivers' putc() should be calling watchdog reset, does this 
really make sense here ?  looks like a wart in a few arches you shouldnt be 
copying over ...
-mike


signature.asc
Description: This is a digitally signed message part.
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH 2/2] cmd history: Match history buffer size to console buffer

2010-03-21 Thread Wolfgang Denk
Dear John Schmoller,

In message 
ca4aa654e79efc5c561fddeeea7c4d1806654b54.1268408614.git.jschmol...@xes-inc.com
 you wrote:
 Match history buffer size to console buffer size. History buffer size
 was hard coded to 256, artificially limiting the command buffer size.
 The history buffer now tracks CONFIG_SYS_CBSIZE.
 
 Signed-off-by: John Schmoller jschmol...@xes-inc.com
 ---
  common/main.c |2 +-
  1 files changed, 1 insertions(+), 1 deletions(-)

Applied to next branch. Thanks.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
There you go man, Keep as cool as you can. It riles them  to  believe
that you perceive the web they weave. Keep on being free!
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH 5/6] fdt_support: add partitions fixup in mtd node

2010-03-21 Thread Gerald Van Baren
Wolfgang Denk wrote:
 Dear Anatolij Gustschin,
 
 In message 1266964630-7754-6-git-send-email-ag...@denx.de you wrote:
 Allow overriding defined partitions in the device tree blob
 using partition info defined in the 'mtdparts' environment
 variable.

 Signed-off-by: Anatolij Gustschin ag...@denx.de
 Cc: Gerald Van Baren vanba...@cideas.com
 ---
  common/cmd_mtdparts.c   |2 +-
  common/fdt_support.c|  214 
 +++
  include/fdt_support.h   |2 +
  include/jffs2/load_kernel.h |1 +
  include/mtd_node.h  |   11 ++
  5 files changed, 229 insertions(+), 1 deletions(-)
  create mode 100644 include/mtd_node.h
 
 Applied to next branch, thanks.
 
 Best regards,
 
 Wolfgang Denk

Thanks for applying this,
gvb

___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH 1/2] console: Fix console buffer overrun

2010-03-21 Thread Wolfgang Denk
Dear John Schmoller,

In message 
69e2af90a136fea8e81009f4d58ffe28eddf7362.1268408614.git.jschmol...@xes-inc.com
 you wrote:
 When CONFIG_SYS_CBSIZE equals MAX_CMDBUF_SIZE, a command string of
 maximum length will overwrite part of the history buffer, causing the
 board to die. Expand the console_buffer and hist_lines buffer by one
 character each to hold the missing NULL char.
 
 Signed-off-by: John Schmoller jschmol...@xes-inc.com
 ---
  common/main.c |4 ++--
  1 files changed, 2 insertions(+), 2 deletions(-)

Applied to next branch. Thanks.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Every solution breeds new problems.
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH] mxcmmc: fix warnings due to access 32 bit registers with 16 bit accessors

2010-03-21 Thread Wolfgang Denk
Dear Stefano Babic,

In message 1268510940-7266-1-git-send-email-sba...@denx.de you wrote:
 Some registers of the mxcmmc driver were accessed using
 16 bit accessor functions, because only the LSB is
 significant. This is not needed and generates
 warnings.
 
 Signed-off-by: Stefano Babic sba...@denx.de
 ---
 
 Tested on imx27lite board.
 
  drivers/mmc/mxcmmc.c |   36 ++--
  1 files changed, 18 insertions(+), 18 deletions(-)

Applied, thanks.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Pain is a thing of the mind.  The mind can be controlled.
-- Spock, Operation -- Annihilate! stardate 3287.2
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH] mod change 755 = 644 for multiple files

2010-03-21 Thread Wolfgang Denk
Dear Thomas Weber,

In message 1268518485-28728-1-git-send-email-sw...@gmx.li you wrote:
 I executed 'find . -name *.[chS] -perm 755 -exec chmod 644 {} \;'
 
 Signed-off-by: Thomas Weber sw...@gmx.li
 ---
  0 files changed, 0 insertions(+), 0 deletions(-)
  mode change 100755 = 100644 board/spear/common/spr_lowlevel_init.S
  mode change 100755 = 100644 board/spear/common/spr_misc.c
  mode change 100755 = 100644 board/spear/spear300/spear300.c
  mode change 100755 = 100644 board/spear/spear310/spear310.c
  mode change 100755 = 100644 board/spear/spear320/spear320.c
  mode change 100755 = 100644 board/spear/spear600/spear600.c
  mode change 100755 = 100644 cpu/arm926ejs/spear/reset.c
  mode change 100755 = 100644 cpu/arm926ejs/spear/timer.c
  mode change 100755 = 100644 cpu/arm926ejs/versatile/timer.c
  mode change 100755 = 100644 drivers/i2c/spr_i2c.c
  mode change 100755 = 100644 drivers/mtd/nand/spr_nand.c
  mode change 100755 = 100644 drivers/mtd/spr_smi.c
  mode change 100755 = 100644 drivers/serial/usbtty.h
  mode change 100755 = 100644 drivers/usb/gadget/spr_udc.c
  mode change 100755 = 100644 include/asm-arm/arch-spear/spr_gpt.h
  mode change 100755 = 100644 include/asm-arm/arch-spear/spr_i2c.h
  mode change 100755 = 100644 include/asm-arm/arch-spear/spr_smi.h
  mode change 100755 = 100644 include/asm-arm/arch-spear/spr_xloader_table.h
  mode change 100755 = 100644 include/configs/spear3xx.h
  mode change 100755 = 100644 include/configs/spear6xx.h
  mode change 100755 = 100644 include/usb/spr_udc.h
  mode change 100755 = 100644 lib_m68k/bootm.c

Thanks, applied (and added some more, as neither Makefile nore
config.mk need execute permissions).

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
What can it profit a man to gain the whole world and to come  to  his
property with a gastric ulcer, a blown prostate, and bifocals?
 -- John Steinbeck, _Cannery Row_
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


[U-Boot] [PATCH 3/3] fsl-ddr: add the macro for Rtt_Nom definition

2010-03-21 Thread Kumar Gala
From: Dave Liu dave...@freescale.com

add the macro definition for Rtt_Nom termination value for DDR3

Signed-off-by: Dave Liu dave...@freescale.com
---
 include/asm-ppc/fsl_ddr_sdram.h |8 +++-
 1 files changed, 7 insertions(+), 1 deletions(-)

diff --git a/include/asm-ppc/fsl_ddr_sdram.h b/include/asm-ppc/fsl_ddr_sdram.h
index 3216a50..02920db 100644
--- a/include/asm-ppc/fsl_ddr_sdram.h
+++ b/include/asm-ppc/fsl_ddr_sdram.h
@@ -1,5 +1,5 @@
 /*
- * Copyright 2008-2009 Freescale Semiconductor, Inc.
+ * Copyright 2008-2010 Freescale Semiconductor, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,6 +24,12 @@
 #define DDR_OTF6   /* on-the-fly BC4 and BL8 */
 #define DDR_BL88   /* burst length 8 */
 
+#define DDR3_RTT_60_OHM1 /* RTT_Nom = RZQ/4 */
+#define DDR3_RTT_120_OHM   2 /* RTT_Nom = RZQ/2 */
+#define DDR3_RTT_40_OHM3 /* RTT_Nom = RZQ/6 */
+#define DDR3_RTT_20_OHM4 /* RTT_Nom = RZQ/12 */
+#define DDR3_RTT_30_OHM5 /* RTT_Nom = RZQ/8 */
+
 #if defined(CONFIG_FSL_DDR1)
 #define FSL_DDR_MIN_TCKE_PULSE_WIDTH_DDR   (1)
 typedef ddr1_spd_eeprom_t generic_spd_eeprom_t;
-- 
1.6.0.6

___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


[U-Boot] [PATCH 2/3] fsl-ddr: change the default burst mode for DDR3

2010-03-21 Thread Kumar Gala
From: Dave Liu dave...@freescale.com

For 64B cacheline SoC, set the fixed 8-beat burst len,
for 32B cacheline SoC, set the On-The-Fly as default.

Signed-off-by: Dave Liu dave...@freescale.com
---
 cpu/mpc8xxx/ddr/options.c |7 ++-
 1 files changed, 6 insertions(+), 1 deletions(-)

diff --git a/cpu/mpc8xxx/ddr/options.c b/cpu/mpc8xxx/ddr/options.c
index 3dcd33d..8e62279 100644
--- a/cpu/mpc8xxx/ddr/options.c
+++ b/cpu/mpc8xxx/ddr/options.c
@@ -1,5 +1,5 @@
 /*
- * Copyright 2008 Freescale Semiconductor, Inc.
+ * Copyright 2008, 2010 Freescale Semiconductor, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -109,8 +109,13 @@ unsigned int populate_memctl_options(int 
all_DIMMs_registered,
 
/* Choose burst length. */
 #if defined(CONFIG_FSL_DDR3)
+#if defined(CONFIG_E500MC)
+   popts-OTF_burst_chop_en = 0;   /* on-the-fly burst chop disable */
+   popts-burst_length = DDR_BL8;  /* Fixed 8-beat burst len */
+#else
popts-OTF_burst_chop_en = 1;   /* on-the-fly burst chop */
popts-burst_length = DDR_OTF;  /* on-the-fly BC4 and BL8 */
+#endif
 #else
popts-burst_length = DDR_BL4;  /* has to be 4 for DDR2 */
 #endif
-- 
1.6.0.6

___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH 1/3] fsl_esdhc: Always stop clock before changing frequency

2010-03-21 Thread Kumar Gala

On Mar 20, 2010, at 12:54 PM, Stefano Babic wrote:

 Kumar Gala wrote:
 We need to stop the clocks on 83xx/85xx as well as imx.  No need to make
 this code conditional to just imx.
 
 Signed-off-by: Kumar Gala ga...@kernel.crashing.org
 ---
 drivers/mmc/fsl_esdhc.c |   11 +++
 include/fsl_esdhc.h |3 +--
 2 files changed, 4 insertions(+), 10 deletions(-)
 
 
 Agree, but please remove clk_enable from the mx51evk.c, too.
 
 Tested successfully on mx51evk.
 
 Acked-by: Stefano Babic sba...@denx.de

applied to 85xx-next.

- k
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH 2/3] fsl_esdhc: Add function to reset the eSDHC controller

2010-03-21 Thread Kumar Gala

On Mar 20, 2010, at 12:56 PM, Stefano Babic wrote:

 Kumar Gala wrote:
 From: Jerry Huang chang-ming.hu...@freescale.com
 
 To support multiple block read command we must set abort or use auto
 CMD12.  If we booted from eSDHC controller neither of these are used
 and thus we need to reset the controller to allow multiple block read
 to function.
 
 Signed-off-by: Jerry Huang chang-ming.hu...@freescale.com
 Signed-off-by: Roy Zang tie-fei.z...@freescale.com
 
 Tested successfully on mx51evk.
 
 Acked-by: Stefano Babic sba...@denx.de

applied to 85xx-next.

- k
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


[U-Boot] [PATCH v2] fsl_esdhc: Only modify the field we are changing in WML

2010-03-21 Thread Kumar Gala
From: Roy Zang tie-fei.z...@freescale.com

When we set the read or write watermark in WML we should maintain the
rest of the register as is, rather than using some hard coded value.

Signed-off-by: Roy Zang tie-fei.z...@freescale.com
Acked-by: Stefano Babic sba...@denx.de
Signed-off-by: Kumar Gala ga...@kernel.crashing.org
---
* Fixed line length

 drivers/mmc/fsl_esdhc.c |9 -
 include/fsl_esdhc.h |2 ++
 2 files changed, 6 insertions(+), 5 deletions(-)

diff --git a/drivers/mmc/fsl_esdhc.c b/drivers/mmc/fsl_esdhc.c
index 999b581..0f6f8b1 100644
--- a/drivers/mmc/fsl_esdhc.c
+++ b/drivers/mmc/fsl_esdhc.c
@@ -110,8 +110,7 @@ static int esdhc_setup_data(struct mmc *mmc, struct 
mmc_data *data)
if (wml_value  0x10)
wml_value = 0x10;
 
-   wml_value = 0x10 | wml_value;
-
+   esdhc_clrsetbits32(regs-wml, WML_RD_WML_MASK, wml_value);
esdhc_write32(regs-dsaddr, (u32)data-dest);
} else {
if (wml_value  0x80)
@@ -120,12 +119,12 @@ static int esdhc_setup_data(struct mmc *mmc, struct 
mmc_data *data)
printf(\nThe SD card is locked. Can not write to a 
locked card.\n\n);
return TIMEOUT;
}
-   wml_value = wml_value  16 | 0x10;
+
+   esdhc_clrsetbits32(regs-wml, WML_WR_WML_MASK,
+   wml_value  16);
esdhc_write32(regs-dsaddr, (u32)data-src);
}
 
-   esdhc_write32(regs-wml, wml_value);
-
esdhc_write32(regs-blkattr, data-blocks  16 | data-blocksize);
 
/* Calculate the timeout period for data transactions */
diff --git a/include/fsl_esdhc.h b/include/fsl_esdhc.h
index 5f02018..f9ae15a 100644
--- a/include/fsl_esdhc.h
+++ b/include/fsl_esdhc.h
@@ -133,6 +133,8 @@
 
 #define WML0x2e044
 #define WML_WRITE  0x0001
+#define WML_RD_WML_MASK0xff
+#define WML_WR_WML_MASK0xff
 
 #define BLKATTR0x2e004
 #define BLKATTR_CNT(x) ((x  0x)  16)
-- 
1.6.0.6

___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] MPC5200: possible to reserve embedded flash sectors ?

2010-03-21 Thread Wolfgang Denk
Dear André,

In message 1268643615.4089.8.ca...@swa-m460 you wrote:

 Created the board dir and added this line to config.mk:

 LDSCRIPT :$(SRCTREE)/board/matrix-vision/mvsmr/u-boot.lds

 which results in failure during make :

 s...@swa-m460:~/u-boot.git$ CROSS_COMPILEppc_6xx- ARCHpowerpc make
 for dir in tools examples/standalone examples/api
 cpu/mpc5xxx /home/swa/u-boot.git/board/matrix-vision/mvsmr/ ; do \
^^

This comes from these lines in the Makefile:

 407 for dir in $(SUBDIRS) cpu/$(CPU) $(dir $(LDSCRIPT)) ; do \
 408 $(MAKE) -C $$dir _depend ; done

 make: *** /home/swa/u-boot.git/board/matrix-vision/mvsmr/: No such file
 or directory.  Stop.

Well, did you check if there is eally a directory of this name in your
source tree?  There is none in mine...

Usually error messges mean what they say.

 What am I missing ?

The directory /home/swa/u-boot.git/board/matrix-vision/mvsmr/ ?

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Hindsight is an exact science.
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH] console.c: fix problem with splashimage

2010-03-21 Thread Wolfgang Denk
Dear Anatolij Gustschin,

In message 1268749773-4302-1-git-send-email-ag...@denx.de you wrote:
 If a board uses cfb_console driver and splash image
 and also defines CONFIG_SILENT_CONSOLE, the user is
 locked out even if silent is not set. It is not
 possible to get any output, neither on vga console
 device nor on serial console after redirecting the
 output to the serial console, since the GD_FLG_SILENT
 flag remains set.
 
 Fix the problem by redirecting the output from frame
 buffer to serial console if splashimage is used.
 Only suppress the output if silent environment
 variable was set and don't set the GD_FLG_SILENT
 flag arbitrarily.
 
 Signed-off-by: Anatolij Gustschin ag...@denx.de
 ---
  common/console.c |   10 +++---
  1 files changed, 7 insertions(+), 3 deletions(-)

Applied, thanks.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
He is truly wise who gains wisdom from another's mishap.
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH v2 0/7] Add support for PDM360NG board

2010-03-21 Thread Wolfgang Denk
Dear Anatolij Gustschin,

In message 1268755808-24931-1-git-send-email-ag...@denx.de you wrote:
 This patch series intend to support MPC5121e based
 PDM360NG board. Patches preceding the actual board
 support patch 6 prepare needed infrastructure for
 the PDM360NG board.

Argh... so I applied an old version of these patches.  OK, I can still
undo this; no damage done except wasted work and time.

To avoid this in the future please make sure to use proper threading
when you resubmit a patch series - this new submission was in no way
linked to your previous one.  Thanks.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Quantum Mechanics is God's version of Trust me.
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH v2 1/7] mpc512x: make MEM IO Control configuration a board config option

2010-03-21 Thread Wolfgang Denk
Dear Anatolij Gustschin,

In message 1268755808-24931-2-git-send-email-ag...@denx.de you wrote:
 Signed-off-by: Anatolij Gustschin ag...@denx.de
 ---
 No changes since v1.
 
  cpu/mpc512x/fixed_sdram.c|2 +-
  include/asm-ppc/immap_512x.h |4 
  include/configs/aria.h   |2 ++
  include/configs/mecp5123.h   |2 ++
  include/configs/mpc5121ads.h |2 ++
  5 files changed, 7 insertions(+), 5 deletions(-)

Applied to u-boot-mpc5xxx repository. Thanks.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Death. Destruction. Disease. Horror. That's what war  is  all  about.
That's what makes it a thing to be avoided.
-- Kirk, A Taste of Armageddon, stardate 3193.0
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH v2 2/7] mpc512x: add multi serial PSC support

2010-03-21 Thread Wolfgang Denk
Dear Anatolij Gustschin,

In message 1268755808-24931-3-git-send-email-ag...@denx.de you wrote:
 Extend mpc512x serial driver to support multiple PSC ports.
 
 Supsequent patches for PDM360NG board support make use of this
 functionality by defining CONFIG_SERIAL_MULTI in the board config
 file. Additionally the used PSC devices are specified by defining
 e.g. CONFIG_SYS_PSC1, CONFIG_SYS_PSC4 and CONFIG_SYS_PSC6.
 
 Support for PSC devices other than 1, 3, 4 and 6 is not added
 by this patch because these aren't used currently. In the future
 it can be easily added using DECLARE_PSC_SERIAL_FUNCTIONS(N) and
 INIT_PSC_SERIAL_STRUCTURE(N) macros in cpu/mpc512x/serial.c.
 Additionally you have to add code for registering added
 devices in serial_initialise() in common/serial.c.
 
 Signed-off-by: Anatolij Gustschin ag...@denx.de
 ---
 No changes since v1.
 
  common/serial.c  |   23 
  cpu/mpc512x/serial.c |  266 
 +-
  include/asm-ppc/immap_512x.h |  108 +-
  include/serial.h |8 ++
  4 files changed, 324 insertions(+), 81 deletions(-)

Applied to u-boot-mpc5xxx repository. Thanks.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Being schizophrenic is better than living alone.
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH v2 3/7] mpc5121: add PSC serial communication routines

2010-03-21 Thread Wolfgang Denk
Dear Anatolij Gustschin,

In message 1268755808-24931-4-git-send-email-ag...@denx.de you wrote:
 Signed-off-by: Anatolij Gustschin ag...@denx.de
 ---
 No changes since v1.
 
  cpu/mpc512x/serial.c |   87 
 ++
  include/serial.h |7 
  2 files changed, 94 insertions(+), 0 deletions(-)

Applied to u-boot-mpc5xxx repository. Thanks.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Die Scheu vor Verantwortung ist die Krankheit unserer Zeit.
 -- Otto von Bismarck
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH v2 4/7] fdt_support: add partitions fixup in mtd node

2010-03-21 Thread Wolfgang Denk
Dear Anatolij Gustschin,

In message 1268755808-24931-5-git-send-email-ag...@denx.de you wrote:
 Allow overriding defined partitions in the device tree blob
 using partition info defined in the 'mtdparts' environment
 variable.
 
 Signed-off-by: Anatolij Gustschin ag...@denx.de
 Cc: Gerald Van Baren vanba...@cideas.com
 ---
 Changes since first version:
  - in fdt_fixup_mtdparts() check the presence of mtdparts
environment variable and don't proceed with initialisation
if the variable is not defined (suppresses warning while booting).
 
  common/cmd_mtdparts.c   |2 +-
  common/fdt_support.c|  219 
 +++
  include/fdt_support.h   |2 +
  include/jffs2/load_kernel.h |1 +
  include/mtd_node.h  |   11 ++
  5 files changed, 234 insertions(+), 1 deletions(-)
  create mode 100644 include/mtd_node.h

Applied to next branch. Thanks.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
I think there's a world market for about five computers.
 -- attr. Thomas J. Watson (Chairman of the Board, IBM), 1943
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH v2 5/7] mpc5121: add common post_word_load/store code

2010-03-21 Thread Wolfgang Denk
Dear Anatolij Gustschin,

In message 1268755808-24931-6-git-send-email-ag...@denx.de you wrote:
 Add common post_word_load/post_word_store routines
 for all mpc5121 boards. pdm360ng board support added
 by subsequent patches needs these, as it adds a board
 specific POST test.
 
 Signed-off-by: Anatolij Gustschin ag...@denx.de
 ---
 This patch is new in this series. This code was in board
 support file in v1 patch series. Now it is common for
 mpc512x boards.
 
  cpu/mpc512x/Makefile   |1 +
  cpu/mpc512x/commproc.c |   25 +
  2 files changed, 26 insertions(+), 0 deletions(-)
  create mode 100644 cpu/mpc512x/commproc.c

Applied to u-boot-mpc5xxx repository. Thanks.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Mr. Cole's Axiom:
The sum of the intelligence on the planet is a constant;
the population is growing.
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH v2 6/7] mpc5121: add support for PDM360NG board

2010-03-21 Thread Wolfgang Denk
Dear Anatolij Gustschin,

In message 1268755808-24931-7-git-send-email-ag...@denx.de you wrote:
 --===0837153488==
 
 PDM360NG is a MPC5121E based board by ifm ecomatic gmbh.
 
 Signed-off-by: Michael Weiss michael.we...@ifm.com
 Signed-off-by: Anatolij Gustschin ag...@denx.de
 ---
 Changes since first version:
  - don't include RLE8 bitmap support in DIU code,
now it is in common code submitted to U-Boot ML
as separate patch. It is also extended to support
more video formats.
  - fixed e-mail format
  - keep the list of targets sorted in the Makefile
  - move POST code into separate file
  - move post_word_load/store code to common file for
all mpc512x boards
  - create a file with common board config options
for mpc512x boards which can be included in the
board config file.
  - use cfb_console driver for frame buffer support
  - allow configuration of coprocessor communication
parameters (baudrate, wait delay) in the board config
file

I see you already addressed a number of issues I mentioned in my
previous review of this patch.

Some others are still open:

  MAKEALL |1 +
  Makefile|3 +
  board/freescale/common/fsl_diu_fb.c |   29 ++-
  board/pdm360ng/Makefile |   52 
  board/pdm360ng/config.mk|   24 ++
  board/pdm360ng/pdm360ng.c   |  525 
 +++
  board/pdm360ng/post.c   |   75 +
  cpu/mpc512x/diu.c   |   14 +-
  include/configs/mpc5121-common.h|   52 
  include/configs/pdm360ng.h  |  520 ++
  include/post.h  |1 +
  post/tests.c|4 +
  12 files changed, 1294 insertions(+), 6 deletions(-)
  create mode 100644 board/pdm360ng/Makefile
  create mode 100644 board/pdm360ng/config.mk
  create mode 100644 board/pdm360ng/pdm360ng.c
  create mode 100644 board/pdm360ng/post.c
  create mode 100644 include/configs/mpc5121-common.h
  create mode 100644 include/configs/pdm360ng.h

Entry to MAINTAINERS file is missing.


 +#if defined(CONFIG_HARD_I2C)
 + if (!getenv(ethaddr)) {
 + uchar buf[6];
 + char mac[18];
 + int ret;
 +
 + /* I2C-0 for on-board eeprom */
 + i2c_set_bus_num(CONFIG_SYS_I2C_EEPROM_BUS_NUM);
 +
 + /* Read ethaddr from EEPROM */
 + ret = i2c_read(CONFIG_SYS_I2C_EEPROM_ADDR,
 +CONFIG_SYS_I2C_EEPROM_MAC_OFFSET, 1, buf, 6);
 + if (!ret) {
 + sprintf(mac, %02X:%02X:%02X:%02X:%02X:%02X,
 + buf[0], buf[1], buf[2], buf[3], buf[4], buf[5]);
 + /* Owned by IFM ? */
 + if (strstr(mac, 00:02:01) != mac) {
 + printf(Illegal MAC address in EEPROM: %s\n,
 +mac);
 + } else {
 + debug(Using MAC from I2C EEPROM: %s\n, mac);
 + setenv(ethaddr, mac);
 + }
 + } else {
 + printf(Error: Unable to read MAC from I2C
 +  EEPROM at address %02X:%02X\n,
 + CONFIG_SYS_I2C_EEPROM_ADDR,
 + CONFIG_SYS_I2C_EEPROM_MAC_OFFSET);
 + }

Please see comments in previous message. IMHO this needs to be
rewritten.

 +#if defined(CONFIG_SERIAL_MULTI)
 +/*
 + * If argument is NULL, set the LCD brightness to the
 + * value from brightness environment variable. Set
 + * the LCD brightness to the value specified by the
 + * argument otherwise. Default brightness is zero.
 + */
 +#define MAX_BRIGHTNESS   99
 +static int set_lcd_brightness(char *brightness)

This seems wrong to me. Why does LCD related code depend on
CONFIG_SERIAL_MULTI ???

 diff --git a/cpu/mpc512x/diu.c b/cpu/mpc512x/diu.c
 index a24f395..fc43a9d 100644
 --- a/cpu/mpc512x/diu.c
 +++ b/cpu/mpc512x/diu.c
 @@ -68,8 +68,13 @@ char *valid_bmp(char *addr)
   unsigned long h_addr;
  
   h_addr = simple_strtoul(addr, NULL, 16);
 - if (h_addr  CONFIG_SYS_FLASH_BASE ||
 - h_addr = (CONFIG_SYS_FLASH_BASE + 
 CONFIG_SYS_FLASH_SIZE - 1)) {
 + if ((h_addr  CONFIG_SYS_FLASH_BASE ||
 + h_addr = (CONFIG_SYS_FLASH_BASE + CONFIG_SYS_FLASH_SIZE - 1))
 +#if defined(CONFIG_SYS_FLASH1_BASE)  defined(CONFIG_SYS_FLASH1_SIZE)
 + (h_addr  CONFIG_SYS_FLASH1_BASE ||
 +h_addr = (CONFIG_SYS_FLASH1_BASE + CONFIG_SYS_FLASH1_SIZE - 1))
 +#endif
 + ) {

I don't like this.  Why do we see hardcoded values here and not the
data from the CFI driver's auto-sizing?  I assume both flash banks are
maped into one big contiguous array of NOR flash, right? Then there
should be just a single test for  base || (base+size) here, using
the total size of the 

Re: [U-Boot] [PATCH v2 7/7] mpc5121: cpu/mpc512x/diu.c: fix warnings

2010-03-21 Thread Wolfgang Denk
Dear Anatolij Gustschin,

In message 1268755808-24931-8-git-send-email-ag...@denx.de you wrote:
 Fix warnings while compiling with CONFIG_VIDEO enabled:
 
 diu.c: In function 'video_hw_init':
 diu.c:158: warning: 'return' with no value, in function returning non-void
 diu.c:162: warning: format '%ld' expects type 'long int', but argument 6 has 
 type 'int'
 diu.c:162: warning: format '%ld' expects type 'long int', but argument 7 has 
 type 'int'
 
 Signed-off-by: Anatolij Gustschin ag...@denx.de
 ---
 New patch in this series, needed after cfb_console driver activation.
 
  cpu/mpc512x/diu.c |4 ++--
  1 files changed, 2 insertions(+), 2 deletions(-)

Applied, thanks.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Hi there! This is just a note from me, to you, to tell you, the  per-
son  reading this note, that I can't think up any more famous quotes,
jokes, nor bizarre stories, so you may as well go home.
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH] nios2: Add missing Ethernet initialization to board_init().

2010-03-21 Thread Scott McNutt
Mike Frysinger wrote:
 On Sunday 21 March 2010 13:37:53 Scott McNutt wrote:
 +WATCHDOG_RESET ();
 +puts (Net:   );
 
 considering serial drivers' putc() should be calling watchdog reset, does 
 this 
 really make sense here ?

No.

 looks like a wart in a few arches you shouldnt be 
 copying over ...

Agreed. Warts can become difficult to remove. ;-)

Regards,
--Scott

___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] cross compiling fw_printenv on big endian

2010-03-21 Thread Wolfgang Denk
Dear Jeff Angielski,

In message 4ba12af2.4080...@theptrgroup.com you wrote:

 Subject: [PATCH] env: fix endian ordering in crc table
 
 The crc table was being built as little endian for big endian
 targets.  This would cause fw_printenv to always fail with
 Warning: Bad CRC, using default environment messages.
 Signed-off-by: Jeff Angielski j...@theptrgroup.com
 ---
  lib_generic/crc32.c |2 +-
  1 files changed, 1 insertions(+), 1 deletions(-)

Applied, thanks.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Mirrors should reflect a little before throwing back images.
- Jean Cocteau
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


[U-Boot] [PATCH] nios2: Add support for EPCS16 and EPCS64 configuration devices.

2010-03-21 Thread Scott McNutt
Signed-off-by: Scott McNutt smcn...@psyent.com
---
 cpu/nios2/epcs.c |   12 
 1 files changed, 8 insertions(+), 4 deletions(-)

diff --git a/cpu/nios2/epcs.c b/cpu/nios2/epcs.c
index 483b249..a2e3fe3 100644
--- a/cpu/nios2/epcs.c
+++ b/cpu/nios2/epcs.c
@@ -207,6 +207,8 @@ static void epcs_status_wr (unsigned char status)
 static struct epcs_devinfo_t devinfo[] = {
{ EPCS1 , 0x10, 17, 4, 15, 8, 0x0c },
{ EPCS4 , 0x12, 19, 8, 16, 8, 0x1c },
+   { EPCS16, 0x14, 21, 32, 16, 8, 0x1c },
+   { EPCS64, 0x16, 23,128, 16, 8, 0x1c },
{ 0, 0, 0, 0, 0, 0 }
 };
 
@@ -501,15 +503,17 @@ void do_epcs_info (struct epcs_devinfo_t *dev, int argc, 
char *argv[])
}
 
/* Sector info */
-   for (i=0; idev-num_sects; i++) {
+   for (i=0; (i  dev-num_sects)  (argc  1); i++) {
erased = epcs_sect_erased (i, tmp, dev);
-   printf ( %d: %06x ,
+   if ((i  0x03) == 0) printf (\n);
+   printf (%4d: %07x ,
i, i*(1dev-sz_sect) );
if (erased)
-   printf (erased\n);
+   printf (E );
else
-   printf (data @ 0x%06x\n, tmp);
+   printf (  );
}
+   printf (\n);
 
return;
 }
-- 
1.6.0.6

___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH 0/8] ST-Ericsson Ux500 support

2010-03-21 Thread Wolfgang Denk
Dear Tom,

In message 1268886061-6382-1-git-send-email-rabin.vinc...@stericsson.com 
Rabin Vincent wrote:
 This series adds base support for ST-Ericsson's Ux500 series of Cortex-A9 
 based
 SoCs.  Several peripherals are shared with the Nomadik family, for which
 support already exists in U-Boot.
 
 Note: The series must be applied on top of the patch [PATCH V4] Nomadik: fix
 reset_timer() posted by Alessandro Rubini on 2009-11-25:
 http://lists.denx.de/pipermail/u-boot/2009-November/064800.html
 Cc: Alessandro Rubini rub...@unipv.it
 
 Rabin Vincent (8):
   Nomadik: move timer code to drivers/misc
   Nomadik: move gpio driver to drivers/gpio
   nomadik_gpio: get base address from platform code
   nomadik_mtu: support configurable clock rates
   ARM Cortex A8: ifdef code calling lowlevel init
   ux500: add SoC-specific code
   pl01x: add support for Ux500 variant of pl011
   mop500: add board-specific files

Reviewed-by: Wolfgang Denk w...@denx.de

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
READ THIS BEFORE OPENING PACKAGE: According to Certain Suggested Ver-
sions of the Grand Unified Theory, the Primary Particles Constituting
this Product May Decay to Nothingness Within the  Next  Four  Hundred
Million Years.
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH v2] Marvell GuruPlug Board Support

2010-03-21 Thread Wolfgang Denk
Dear Tom, dear Prafulla,

In message 1268898134-10793-1-git-send-email-go...@marvell.com you wrote:
 GuruPlug Standard: 1 Gb Ethernet, 2 USB 2.0
 GuruPlug Plus: 2 Gb Ethernet, 2 USB 2.0, 1 eSATA, 1 uSD slot
 
 References:
 http://www.globalscaletechnologies.com/t-guruplugdetails.aspx
 http://plugcomputer.org
 
 This patch is for GuruPlug Plus, but it supports Standard version
 as well.
 
 Signed-off-by: Siddarth Gore go...@marvell.com
 ---
 Changes compared to the previous version (messaage-id:
 1268660568-23022-1-git-send-email-go...@marvell.com)
 - maintainers entry sorted according to last name
 - removed trailing comment from board/Marvell/guruplug/config.mk
 - removed CONFIG_CMD_AUTOSCRIPT from include/configs/guruplug.h
 - removed word 'minimal' from comment in include/configs/guruplug.h
 
  MAINTAINERS |4 +
  MAKEALL |1 +
  Makefile|3 +
  board/Marvell/guruplug/Makefile |   51 +
  board/Marvell/guruplug/config.mk|   27 +
  board/Marvell/guruplug/guruplug.c   |  167 +
  board/Marvell/guruplug/guruplug.h   |   39 +++
  board/Marvell/guruplug/kwbimage.cfg |  162 
  include/configs/guruplug.h  |  198 
 +++
  9 files changed, 652 insertions(+), 0 deletions(-)
  create mode 100644 board/Marvell/guruplug/Makefile
  create mode 100644 board/Marvell/guruplug/config.mk
  create mode 100644 board/Marvell/guruplug/guruplug.c
  create mode 100644 board/Marvell/guruplug/guruplug.h
  create mode 100644 board/Marvell/guruplug/kwbimage.cfg
  create mode 100644 include/configs/guruplug.h

Reviewed-by: Wolfgang Denk w...@denx.de

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Every little picofarad has a nanohenry all its own.  - Don Vonada
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH] correct a syntax typo in at91_matrix.h

2010-03-21 Thread Wolfgang Denk
Dear Asen Dimov,

In message 1268912507-7542-1-git-send-email-di...@ronetix.at you wrote:
 
 Signed-off-by: Asen Dimov di...@ronetix.at
 ---
  include/asm-arm/arch-at91/at91_matrix.h |2 +-
  1 files changed, 1 insertions(+), 1 deletions(-)

Applied, thanks.

Tom, as this is a simple typo I went ahead and applied this directly;
hope this is OK with you.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
An open mind has but one disadvantage: it collects dirt.
- a saying at RPI
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH] add new board pm9g45

2010-03-21 Thread Wolfgang Denk
Dear Tom,

In message 4ba51dad.5020...@windriver.com you wrote:
 Asen Dimov wrote:
  Hello everyone,
  
  here is the new board PM9G45 from Ronetix GmbH,
  based on at91sam9g45 MCU. It has 128MB DDR2 SDRAM, 256MB NAND,
  could be with or without DataFlash. 
  The board is made as SODIMM200 module.
  For more info www.ronatix.at or i...@ronetix.at.
  
  Regards,
  Asen
 
 There are some errors on building with MAKEALL arm
 These must be fixed

Could you please make sure to include threading information (i. e.
appropriate References: and In-reply-to: mail headers)?

It would be nice if we could see which message your postings refer
to.

Thanks.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Philosophy:  A route of many roads leading from nowhere to nothing.
- Ambrose Bierce
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] uboot on microblaze, compilation error

2010-03-21 Thread Wolfgang Denk
Dear Mike Frysinger,

In message 201003182111.28112.vap...@gentoo.org you wrote:

 i dont think the toolchain is broken.  this is standard gcc behavior for all 
 arches. ...

You are wrong here. It _is_ a bug of the toolchain if it auto-defines
random unreserved identifiers.  This is NOT standard GCC behaviour.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
An Elephant is a mouse with an Operating System.  - Knuth
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH 00/28] u-boot next: a generic approach for nios2 arch

2010-03-21 Thread Wolfgang Denk
Dear Peter,

In message 1269032821.7363.27.ca...@ptyser-laptop you wrote:
 
 I personally think that looking at a deep threaded patch series with
 lots of responses is much harder to grasp than the shallow threaded.
 As a basic example:
 http://article.gmane.org/gmane.comp.version-control.git/109790

Thanks for the link - I was not aware of this discussion.

 I would guess that the majority of other users prefer the shallow
 threaded style too.

I can only guess that, too. But I know my own preferences :-)

 I'm pretty sure in the --no-chain-reply-to case, git makes sure the
 email dates increment properly, and no 2 are the same.  Thus any sane
 email client should order them properly when using shallow threading.

IIRC git-send-email will indeed make sure to have at least second
increments.

 I believe the default behavior of git has also been changed to
 --no-chain-reply-to for what its worth.  The fact that patch order can
 be determined by both timestamp and patch title (assuming proper
 generation) seems sufficient to me to use the --no-chain-reply-to
 option.

Well, as the default behavior has been changed, it seems I'm overruled
anyway, and there is no need to take additional action.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Never worry about theory as long as  the  machinery  does  what  it's
supposed to do.  - R. A. Heinlein
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] [PATCH] net/eth.c: bug-fix

2010-03-21 Thread Wolfgang Denk
Dear Ben,

In message 3270dcac1b1540c7b13d9bc718f54...@smartbridges.com Teh Kok How 
wrote:
 Fixes: Board_eth_init() calls pci_eth_init() (include/netdev.h) and if
 ethernet is soc, CONFIG_PCI is not defined, pci_eth_init() returns 0.
 This patch allows cpu_eth_init() to be called.
 
 
 Signed-off-by: Kok How, Teh k_h_...@yahoo.com
 --- u-boot-2009.11.1.orig/net/eth.c 2010-01-25 16:35:12.0 +0800
 +++ u-boot-2009.11.1.new/net/eth.c  2010-02-12 17:20:32.864273873 +0800
 @@ -199,7 +199,7 @@
  #endif
 /* Try board-specific initialization first.  If it fails or isn't
  * present, try the cpu-specific initialization */
 -   if (board_eth_init(bis)  0)
 +   if (board_eth_init(bis) = 0)
 cpu_eth_init(bis);
 
  #if defined(CONFIG_DB64360) || defined(CONFIG_CPCI750)
 

Do you have this patch in your queue?

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Abstainer: A weak person who yields to the temptation of denying him-
self a pleasure. A total abstainer is one who  abstains  from  every-
thing  but  abstention, and especially from inactivity in the affairs
of others.   - Ambrose Bierce
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


[U-Boot] PULL REQUEST (for next): please pull u-boot-mpc5xxx

2010-03-21 Thread Wolfgang Denk
The following changes since commit 67c7189dd35cb368ef665126fd17816581bd2e92:
  Renato Andreola (1):
nios2: Added support to YANU UART

are available in the git repository at:

  git://git.denx.de/u-boot-mpc5xxx.git master

Anatolij Gustschin (4):
  mpc512x: make MEM IO Control configuration a board config option
  mpc512x: add multi serial PSC support
  mpc5121: add PSC serial communication routines
  mpc5121: add common post_word_load/store code

 common/serial.c  |   23 +++
 cpu/mpc512x/Makefile |1 +
 cpu/mpc512x/commproc.c   |   25 +++
 cpu/mpc512x/fixed_sdram.c|2 +-
 cpu/mpc512x/serial.c |  353 ++
 include/asm-ppc/immap_512x.h |  112 +++---
 include/configs/aria.h   |2 +
 include/configs/mecp5123.h   |2 +
 include/configs/mpc5121ads.h |2 +
 include/serial.h |   15 ++
 10 files changed, 451 insertions(+), 86 deletions(-)
 create mode 100644 cpu/mpc512x/commproc.c
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] PULL REQUEST (for next): please pull u-boot-mpc5xxx

2010-03-21 Thread Wolfgang Denk
In message 20100321214009.827ff4c...@gemini.denx.de you wrote:
 The following changes since commit 67c7189dd35cb368ef665126fd17816581bd2e92:
   Renato Andreola (1):
 nios2: Added support to YANU UART
 
 are available in the git repository at:
 
   git://git.denx.de/u-boot-mpc5xxx.git master
 
 Anatolij Gustschin (4):
   mpc512x: make MEM IO Control configuration a board config option
   mpc512x: add multi serial PSC support
   mpc5121: add PSC serial communication routines
   mpc5121: add common post_word_load/store code
 
  common/serial.c  |   23 +++
  cpu/mpc512x/Makefile |1 +
  cpu/mpc512x/commproc.c   |   25 +++
  cpu/mpc512x/fixed_sdram.c|2 +-
  cpu/mpc512x/serial.c |  353 
 ++
  include/asm-ppc/immap_512x.h |  112 +++---
  include/configs/aria.h   |2 +
  include/configs/mecp5123.h   |2 +
  include/configs/mpc5121ads.h |2 +
  include/serial.h |   15 ++
  10 files changed, 451 insertions(+), 86 deletions(-)
  create mode 100644 cpu/mpc512x/commproc.c

Applied.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
Another war ... must it always be so?  How many comrades have we lost
in this way? ...  Obedience.  Duty.  Death, and more death ...
-- Romulan Commander, Balance of Terror, stardate 1709.2
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


[U-Boot] Adding new partition in uboot

2010-03-21 Thread Sagar Heroorkar
Hi David,

I was exploring the ways to add partition into the blob dynamically.

I followd the following steps.

1) say we have 5 partitions.  Flash size is 128mb

norfl...@0,0{
1--
2--
3

5
  partit...@f8 {
label = u_booot;
reg = 0xf8 0x6;
};

2) i am trying to add 6th partition dynamically in uboot.

   I used the the nodeoffset of norfl...@0,0 which is parent offset wher i
want to create 6th partiton. I passed  this parent offset to
ret  =  fdt_add_subnode(blob,nodeoffset, partit...@680);
nodeoffset = ret;
ptr[0] = 0x680;
ptr[1] = 0x80;
offset = 0x680;
regs[0] += size_delta;
memcpy(regs, ptr, plen);
ret = fdt_setprop(blob, nodeoffset, reg, regs, plen);

I am printing the the blob later. i see that node is created but the last
partition ie u-boot @ f8  is going away.

the blob size is 8000 byes which we built using the

dtc -S 8000 -R 7 -I dts -O dtb -o file.dtb file.dts


Let me know if we need to increase size of the blob or something which i m
missing.
This is going to help  a lot if you can reply.

-Sagar
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] uboot on microblaze, compilation error

2010-03-21 Thread Mike Frysinger
On Sunday 21 March 2010 16:00:29 Wolfgang Denk wrote:
 Mike Frysinger wrote:
  i dont think the toolchain is broken.  this is standard gcc behavior for
  all arches. ...
 
 You are wrong here. It _is_ a bug of the toolchain if it auto-defines
 random unreserved identifiers.  This is NOT standard GCC behaviour.

they arent random, it's the arch-specific identifier.  and most arches do 
exactly that with gcc.  try actually looking at the builtins provided by x86, 
mips, and powerpc to mention just a few.
-mike


signature.asc
Description: This is a digitally signed message part.
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] PULL REQUEST (for next): please pull u-boot-mpc5xxx

2010-03-21 Thread Wolfgang Denk
Dear Anatolij,

In message 20100321214723.74b904c...@gemini.denx.de you wrote:
 In message 20100321214009.827ff4c...@gemini.denx.de you wrote:
  The following changes since commit 67c7189dd35cb368ef665126fd17816581bd2e92:
Renato Andreola (1):
  nios2: Added support to YANU UART
  
  are available in the git repository at:
  
git://git.denx.de/u-boot-mpc5xxx.git master
  
  Anatolij Gustschin (4):
mpc512x: make MEM IO Control configuration a board config option
mpc512x: add multi serial PSC support
mpc5121: add PSC serial communication routines
mpc5121: add common post_word_load/store code
  
   common/serial.c  |   23 +++
   cpu/mpc512x/Makefile |1 +
   cpu/mpc512x/commproc.c   |   25 +++
   cpu/mpc512x/fixed_sdram.c|2 +-
   cpu/mpc512x/serial.c |  353 
  ++
   include/asm-ppc/immap_512x.h |  112 +++---
   include/configs/aria.h   |2 +
   include/configs/mecp5123.h   |2 +
   include/configs/mpc5121ads.h |2 +
   include/serial.h |   15 ++
   10 files changed, 451 insertions(+), 86 deletions(-)
   create mode 100644 cpu/mpc512x/commproc.c
 
 Applied.

And reverted again.

Your commit:

commit d774442c60756a8dd5d75de85574120ce375bd72
Author: Anatolij Gustschin ag...@denx.de
Date:   Tue Mar 16 17:10:03 2010 +0100

mpc512x: add multi serial PSC support

breaks a large number of boards really hard because it adds a new
entry (uninit()) to struct serial_device in include/serial.h,
without fixing all the places where such a struct gets initialized;
this results in tons of warnings like these:

serial.c:321: warning: initialization from incompatible pointer type
serial.c:321: warning: initialization from incompatible pointer type
serial.c:321: warning: initialization from incompatible pointer type
serial.c:321: warning: initialization from incompatible pointer type
serial.c:324: warning: initialization from incompatible pointer type
serial.c:324: warning: initialization from incompatible pointer type
serial.c:324: warning: initialization from incompatible pointer type
serial.c:324: warning: initialization from incompatible pointer type
serial.c:327: warning: initialization from incompatible pointer type
serial.c:327: warning: initialization from incompatible pointer type
serial.c:327: warning: initialization from incompatible pointer type
serial.c:327: warning: initialization from incompatible pointer type
serial.c:330: warning: initialization from incompatible pointer type
serial.c:330: warning: initialization from incompatible pointer type
serial.c:330: warning: initialization from incompatible pointer type
serial.c:330: warning: initialization from incompatible pointer type

and (even worse) in bricking all these boards.


Please make sure to run MAKEALL when submitting patches!!!


[I'll leave this code as is in the u-boot-mpc5xxx repo for now, but I
will rebase this as soon as you submit a fix.]

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
We Americans, we're a simple people... but piss us  off,  and  we'll
bomb your cities.   - Robin Williams, _Good Morning Vietnam_
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


Re: [U-Boot] uboot on microblaze, compilation error

2010-03-21 Thread Wolfgang Denk
Dear Mike,

In message 201003211820.51966.vap...@gentoo.org you wrote:

  You are wrong here. It _is_ a bug of the toolchain if it auto-defines
  random unreserved identifiers.  This is NOT standard GCC behaviour.
 
 they arent random, it's the arch-specific identifier.  and most arches do 
 exactly that with gcc.  try actually looking at the builtins provided by x86, 
 mips, and powerpc to mention just a few.

As far as I can tell these are neither part of the Standard Predefined
Macros nor of the Common Predefined Macros, so these can only be part
of the System-Specific Predefined Macros.

And the C standard requires that all System-Specific Macros be part
of the _reserved_namespace_ (i. e. the names must begin with two
underscores, or an underscore and a capital letter).

So if a C compiler auto-defines something as arm, or i386, or
microblaze, then it is NOT standard-conforming - bare with me if I
simply call this broken.

Best regards,

Wolfgang Denk

-- 
DENX Software Engineering GmbH, MD: Wolfgang Denk  Detlev Zundel
HRB 165235 Munich, Office: Kirchenstr.5, D-82194 Groebenzell, Germany
Phone: (+49)-8142-66989-10 Fax: (+49)-8142-66989-80 Email: w...@denx.de
There are two ways of constructing a software design. One way  is  to
make  it  so  simple that there are obviously no deficiencies and the
other is to make it so complicated that there are  no  obvious  defi-
ciencies. - Charles Anthony Richard Hoare
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


[U-Boot] [PATCH] nios2: Fix outx/writex parameter order in io.h

2010-03-21 Thread Scott McNutt
   The outx/writex macros were using writex(addr, val) rather than
   the standard writex(val, addr), resulting in incompatibilty with
   architecture independent components. This change set uses standard
   parameter order.

Signed-off-by: Scott McNutt smcn...@psyent.com
---
 board/altera/common/AMDLV065D.c   |   18 +-
 board/altera/common/epled.c   |6 +++---
 board/psyent/common/AMDLV065D.c   |   18 +-
 board/psyent/pk1c20/led.c |6 +++---
 cpu/nios2/epcs.c  |6 +++---
 cpu/nios2/interrupts.c|   16 
 drivers/serial/altera_jtag_uart.c |2 +-
 drivers/serial/altera_uart.c  |4 ++--
 drivers/serial/opencores_yanu.c   |   12 ++--
 include/asm-nios2/io.h|   18 +-
 10 files changed, 53 insertions(+), 53 deletions(-)

diff --git a/board/altera/common/AMDLV065D.c b/board/altera/common/AMDLV065D.c
index 0fcf354..72b0a9f 100644
--- a/board/altera/common/AMDLV065D.c
+++ b/board/altera/common/AMDLV065D.c
@@ -122,12 +122,12 @@ int flash_erase (flash_info_t * info, int s_first, int 
s_last)
for (sect = s_first; sect = s_last; sect++) {
if (info-protect[sect] == 0) { /* not protected */
addr2 = (unsigned char *) info-start[sect];
-   writeb (addr, 0xaa);
-   writeb (addr,  0x55);
-   writeb (addr,  0x80);
-   writeb (addr,  0xaa);
-   writeb (addr,  0x55);
-   writeb (addr2, 0x30);
+   writeb (0xaa, addr);
+   writeb (0x55, addr);
+   writeb (0x80, addr);
+   writeb (0xaa, addr);
+   writeb (0x55, addr);
+   writeb (0x30, addr2);
/* Now just wait for 0xff  provide some user
 * feedback while we wait.
 */
@@ -169,9 +169,9 @@ int write_buff (flash_info_t * info, uchar * src, ulong 
addr, ulong cnt)
return (2);
}
 
-   writeb (cmd,  0xaa);
-   writeb (cmd,  0x55);
-   writeb (cmd,  0xa0);
+   writeb (0xaa, cmd);
+   writeb (0x55, cmd);
+   writeb (0xa0, cmd);
writeb (dst, b);
 
/* Verify write */
diff --git a/board/altera/common/epled.c b/board/altera/common/epled.c
index e5e7705..d019735 100644
--- a/board/altera/common/epled.c
+++ b/board/altera/common/epled.c
@@ -39,7 +39,7 @@ void __led_init (led_id_t mask, int state)
val = ~mask;
else
val |= mask;
-   writel (pio-data, val);
+   writel (val, pio-data);
 }
 
 void __led_set (led_id_t mask, int state)
@@ -50,7 +50,7 @@ void __led_set (led_id_t mask, int state)
val = ~mask;
else
val |= mask;
-   writel (pio-data, val);
+   writel (val, pio-data);
 }
 
 void __led_toggle (led_id_t mask)
@@ -58,5 +58,5 @@ void __led_toggle (led_id_t mask)
nios_pio_t *pio = (nios_pio_t *)CONFIG_SYS_LEDPIO_ADDR;
 
val ^= mask;
-   writel (pio-data, val);
+   writel (val, pio-data);
 }
diff --git a/board/psyent/common/AMDLV065D.c b/board/psyent/common/AMDLV065D.c
index 0fcf354..72b0a9f 100644
--- a/board/psyent/common/AMDLV065D.c
+++ b/board/psyent/common/AMDLV065D.c
@@ -122,12 +122,12 @@ int flash_erase (flash_info_t * info, int s_first, int 
s_last)
for (sect = s_first; sect = s_last; sect++) {
if (info-protect[sect] == 0) { /* not protected */
addr2 = (unsigned char *) info-start[sect];
-   writeb (addr, 0xaa);
-   writeb (addr,  0x55);
-   writeb (addr,  0x80);
-   writeb (addr,  0xaa);
-   writeb (addr,  0x55);
-   writeb (addr2, 0x30);
+   writeb (0xaa, addr);
+   writeb (0x55, addr);
+   writeb (0x80, addr);
+   writeb (0xaa, addr);
+   writeb (0x55, addr);
+   writeb (0x30, addr2);
/* Now just wait for 0xff  provide some user
 * feedback while we wait.
 */
@@ -169,9 +169,9 @@ int write_buff (flash_info_t * info, uchar * src, ulong 
addr, ulong cnt)
return (2);
}
 
-   writeb (cmd,  0xaa);
-   writeb (cmd,  0x55);
-   writeb (cmd,  0xa0);
+   writeb (0xaa, cmd);
+   writeb (0x55, cmd);
+   writeb (0xa0, cmd);
writeb (dst, b);
 
/* Verify write */
-- 
1.6.0.6

___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot


[U-Boot] [PATCH 1/3] fsl-ddr: Fix the turnaround timing for TIMING_CFG_4

2010-03-21 Thread Kumar Gala
From: Dave Liu dave...@freescale.com

Read-to-read/Write-to-write turnaround for same chip select
of DDR3 memory, BL/2+2 cycles is enough for them at BC4 and
OTF case, BL/2 cycles is enough for fixed BL8.
Cutting down the turnaround from BL/2+4 to BL/2+2 or BL/2
will improve the memory performance.

Signed-off-by: Dave Liu dave...@freescale.com
---
 cpu/mpc8xxx/ddr/ctrl_regs.c |   19 +--
 1 files changed, 13 insertions(+), 6 deletions(-)

diff --git a/cpu/mpc8xxx/ddr/ctrl_regs.c b/cpu/mpc8xxx/ddr/ctrl_regs.c
index adc4f6e..caac943 100644
--- a/cpu/mpc8xxx/ddr/ctrl_regs.c
+++ b/cpu/mpc8xxx/ddr/ctrl_regs.c
@@ -1,5 +1,5 @@
 /*
- * Copyright 2008-2009 Freescale Semiconductor, Inc.
+ * Copyright 2008-2010 Freescale Semiconductor, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -934,7 +934,8 @@ static void set_ddr_init_ext_addr(fsl_ddr_cfg_regs_t *ddr)
 }
 
 /* DDR SDRAM Timing Configuration 4 (TIMING_CFG_4) */
-static void set_timing_cfg_4(fsl_ddr_cfg_regs_t *ddr)
+static void set_timing_cfg_4(fsl_ddr_cfg_regs_t *ddr,
+   const memctl_options_t *popts)
 {
unsigned int rwt = 0; /* Read-to-write turnaround for same CS */
unsigned int wrt = 0; /* Write-to-read turnaround for same CS */
@@ -943,9 +944,15 @@ static void set_timing_cfg_4(fsl_ddr_cfg_regs_t *ddr)
unsigned int dll_lock = 0; /* DDR SDRAM DLL Lock Time */
 
 #if defined(CONFIG_FSL_DDR3)
-   /* We need set BL/2 + 4 for BC4 or OTF */
-   rrt = 4;/* BL/2 + 4 clocks */
-   wwt = 4;/* BL/2 + 4 clocks */
+   if (popts-burst_length == DDR_BL8) {
+   /* We set BL/2 for fixed BL8 */
+   rrt = 0;/* BL/2 clocks */
+   wwt = 0;/* BL/2 clocks */
+   } else {
+   /* We need to set BL/2 + 2 to BC4 and OTF */
+   rrt = 2;/* BL/2 + 2 clocks */
+   wwt = 2;/* BL/2 + 2 clocks */
+   }
dll_lock = 1;   /* tDLLK = 512 clocks from spec */
 #endif
ddr-timing_cfg_4 = (0
@@ -1343,7 +1350,7 @@ compute_fsl_memctl_config_regs(const memctl_options_t 
*popts,
set_ddr_sdram_clk_cntl(ddr, popts);
set_ddr_init_addr(ddr);
set_ddr_init_ext_addr(ddr);
-   set_timing_cfg_4(ddr);
+   set_timing_cfg_4(ddr, popts);
set_timing_cfg_5(ddr);
 
set_ddr_zq_cntl(ddr, zq_en);
diff --git a/board/psyent/pk1c20/led.c b/board/psyent/pk1c20/led.c
index e5e7705..d019735 

Re: [U-Boot] [PATCH 4/6] fsl_diu_fb.c: add support for RLE8 bitmaps

2010-03-21 Thread Timur Tabi
On Wed, Feb 24, 2010 at 5:03 AM, Anatolij Gustschin ag...@denx.de wrote:

 Isn't there a way to implement this feature in common code, so all
 boards with bitmap support can benefit from this?

 There is a way to do it, sure. The problem is, diu driver doesn't
 use this common code. I'll rework the diu driver to do so.

Can you be more specific?  What does the DIU driver do wrong?

-- 
Timur Tabi
Linux kernel developer at Freescale
___
U-Boot mailing list
U-Boot@lists.denx.de
http://lists.denx.de/mailman/listinfo/u-boot